==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectNode.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnode_h
#define objectnode_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_node_enumeration_direction_inout,
  adms_node_enumeration_direction_input,
  adms_node_enumeration_direction_internal,
  adms_node_enumeration_direction_output
} e_node_direction;
win32_interface char* adms_node_tostring_direction_impl (p_admsttransform myadmsttransform,e_node_direction e);
win32_interface e_node_direction adms_node_fromstring_direction_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_node_enumeration_grounded_no,
  adms_node_enumeration_grounded_yes
} e_node_grounded;
win32_interface char* adms_node_tostring_grounded_impl (p_admsttransform myadmsttransform,e_node_grounded e);
win32_interface e_node_grounded adms_node_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_node_enumeration_location_external,
  adms_node_enumeration_location_ground,
  adms_node_enumeration_location_internal
} e_node_location;
win32_interface char* adms_node_tostring_location_impl (p_admsttransform myadmsttransform,e_node_location e);
win32_interface e_node_location adms_node_fromstring_location_impl (p_admsttransform myadmsttransform,char*token);
struct s_node {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  e_node_direction _direction;
  int _direction_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  e_node_grounded _grounded;
  int _grounded_isdefault : 1;
  e_node_location _location;
  int _location_isdefault : 1;
  GSList* _attribute;
  int _attribute_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectAttribute.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_node_getuid (p_node mynode);
win32_interface gboolean adms_node_cmp (p_node mynode,p_node refnode);
win32_interface p_node adms_node_new_1 (p_module mymodule,char* myname);
#define adms_node_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_node_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_node_new_impl (p_adms arguments[]);
win32_interface p_node adms_node_impl (void* member);
#define adms_node(member) ((p_node) (member))
#define adms_node_new adms_node_new_1
#define adms_node_isdefault_module(node) (adms_node(node)->_module_isdefault)
#define adms_node_valueof_module(node) (adms_node(node)->_module)
#define adms_node_isdefault_name(node) (adms_node(node)->_name_isdefault)
#define adms_node_valueof_name(node) (adms_node(node)->_name)
#define adms_node_isdefault_direction(node) (adms_node(node)->_direction_isdefault)
#define adms_node_valueof_direction(node) (adms_node(node)->_direction)
#define adms_node_isdefault_discipline(node) (adms_node(node)->_discipline_isdefault)
#define adms_node_valueof_discipline(node) (adms_node(node)->_discipline)
#define adms_node_isdefault_grounded(node) (adms_node(node)->_grounded_isdefault)
#define adms_node_valueof_grounded(node) (adms_node(node)->_grounded)
#define adms_node_isdefault_location(node) (adms_node(node)->_location_isdefault)
#define adms_node_valueof_location(node) (adms_node(node)->_location)
#define adms_node_isdefault_attribute(node) (adms_node(node)->_attribute_isdefault)
#define adms_node_valueof_attribute(node) (adms_node(node)->_attribute)
#define adms_node_valueof_adms(node) ((p_adms)node)
#define adms_node_valueto_module(a,b) ((p_node)a)->_module=(b)
win32_interface void adms_node_valueto_module_impl (p_node mynode,p_module _module);
#define adms_node_valueto_name(a,b) ((p_node)a)->_name=(b)
win32_interface void adms_node_valueto_name_impl (p_node mynode,char* _name);
#define adms_node_valueto_direction(a,b) ((p_node)a)->_direction=(b)
win32_interface void adms_node_valueto_direction_impl (p_node mynode,e_node_direction _direction);
#define adms_node_valueto_discipline(a,b) ((p_node)a)->_discipline=(b)
win32_interface void adms_node_valueto_discipline_impl (p_node mynode,p_discipline _discipline);
#define adms_node_valueto_grounded(a,b) ((p_node)a)->_grounded=(b)
win32_interface void adms_node_valueto_grounded_impl (p_node mynode,e_node_grounded _grounded);
#define adms_node_valueto_location(a,b) ((p_node)a)->_location=(b)
win32_interface void adms_node_valueto_location_impl (p_node mynode,e_node_location _location);
#define adms_node_valueto_attribute(a,b) ((p_node)a)->_attribute=(b)
win32_interface void adms_node_valueto_attribute_impl (p_node mynode,GSList* _attribute);
win32_interface p_attribute adms_node_list_attribute_lookup_by_id (p_node mymynode,char* myname);
win32_interface p_attribute adms_node_list_attribute_prepend_by_id (p_node mymynode,char* myname);
win32_interface p_attribute adms_node_list_attribute_prepend_by_id_once_or_abort (p_node mymynode,char* myname);
win32_interface void adms_node_list_attribute_prepend_once_or_abort (p_node mymynode,p_attribute myattribute);
#endif /* objectnode_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectNode.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnode_h
#define objectnode_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_node_enumeration_direction_inout,
  adms_node_enumeration_direction_input,
  adms_node_enumeration_direction_internal,
  adms_node_enumeration_direction_output
} e_node_direction;
win32_interface char* adms_node_tostring_direction_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_node_direction adms_node_fromstring_direction_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_node_enumeration_grounded_no,
  adms_node_enumeration_grounded_yes
} e_node_grounded;
win32_interface char* adms_node_tostring_grounded_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_node_grounded adms_node_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_node_enumeration_location_external,
  adms_node_enumeration_location_ground,
  adms_node_enumeration_location_internal
} e_node_location;
win32_interface char* adms_node_tostring_location_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_node_location adms_node_fromstring_location_impl (p_admsttransform myadmsttransform,char*token);
struct s_node {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_enumeration _direction;
  int _direction_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  p_enumeration _grounded;
  int _grounded_isdefault : 1;
  p_enumeration _location;
  int _location_isdefault : 1;
  p_slist _attribute;
  int _attribute_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectEnumeration.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectAttribute.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_node_uid (p_node mynode);
win32_interface int adms_node_cmp (p_node mynode,p_node refnode);
win32_interface p_node adms_node_new(p_module mymodule,p_quark myname);
win32_interface p_adms adms_node_new_impl (p_adms arguments[]);
#define adms_node(member) ((p_node) (member))
#define adms_node_isdefault_module(node) (adms_node(node)->_module_isdefault)
#define adms_node_valueof_module(node) (adms_node(node)->_module)
#define adms_node_isdefault_name(node) (adms_node(node)->_name_isdefault)
#define adms_node_valueof_name(node) (adms_node(node)->_name)
#define adms_node_isdefault_direction(node) (adms_node(node)->_direction_isdefault)
#define adms_node_valueof_direction(node) (adms_node(node)->_direction)
#define adms_node_isdefault_discipline(node) (adms_node(node)->_discipline_isdefault)
#define adms_node_valueof_discipline(node) (adms_node(node)->_discipline)
#define adms_node_isdefault_grounded(node) (adms_node(node)->_grounded_isdefault)
#define adms_node_valueof_grounded(node) (adms_node(node)->_grounded)
#define adms_node_isdefault_location(node) (adms_node(node)->_location_isdefault)
#define adms_node_valueof_location(node) (adms_node(node)->_location)
#define adms_node_isdefault_attribute(node) (adms_node(node)->_attribute_isdefault)
#define adms_node_valueof_attribute(node) (adms_node(node)->_attribute)
#define adms_node_valueof_adms(node) ((p_adms)node)
win32_interface inline void adms_node_valueto_module (p_node mynode,p_module _module);
win32_interface inline void adms_node_valueto_name (p_node mynode,p_quark _name);
win32_interface inline void adms_node_valueto_direction (p_node mynode,p_enumeration _direction);
win32_interface inline void adms_node_valueto_discipline (p_node mynode,p_discipline _discipline);
win32_interface inline void adms_node_valueto_grounded (p_node mynode,p_enumeration _grounded);
win32_interface inline void adms_node_valueto_location (p_node mynode,p_enumeration _location);
win32_interface inline void adms_node_valueto_attribute (p_node mynode,p_slist _attribute);
win32_interface p_attribute adms_node_list_attribute_lookup_by_id (p_node mymynode,p_quark myname);
win32_interface p_attribute adms_node_list_attribute_prepend_by_id (p_node mymynode,p_quark myname);
win32_interface p_attribute adms_node_list_attribute_prepend_by_id_once_or_ignore (p_node mymynode,p_quark myname);
win32_interface void adms_node_list_attribute_prepend (p_node mymynode,p_attribute myattribute);
win32_interface inline void adms_node_free(p_node mynode);
#endif /* objectnode_h */
